/**
 * Namespace for utilities for Module Federation.
 */
export declare namespace Federated {
    /**
     * Creates JavaScript loading code for the given Module Federation remote
     * allowing to import that remote without creating an async boundary, but with
     * simple import statement, eg: `import MyComponent from 'my-remote/MyComponent';`.
     *
     * The returned code should be put as a value inside `remotes` object when configuring
     * `webpack.container.ModuleFederationPlugin`.
     *
     * @param remoteName Name of the container to create remote for.
     * @returns A JavaScript loading code the the given remote.
     *
     * @example
     * ```ts
     * import webpack from 'webpack';
     * import * as Repack from '@callstack/repack';
     *
     * export default (env) => {
     *   return {
     *     plugins: [
     *       new webpack.container.ModuleFederationPlugin({
     *         remotes: {
     *           app1: Repack.Federated.createRemote('app1'),
     *         },
     *       }),
     *     ],
     *   };
     * };
     * ```
     */
    function createRemote(remoteName: string): string;
}
