# Function: createRemote

[Federated](../modules/Federated.md).createRemote

▸ **createRemote**(`remoteName`): `string`

Creates JavaScript loading code for the given Module Federation remote
allowing to import that remote without creating an async boundary, but with
simple import statement, eg: `import MyComponent from 'my-remote/MyComponent';`.

The returned code should be put as a value inside `remotes` object when configuring
`webpack.container.ModuleFederationPlugin`.

**`example`**
```ts
import webpack from 'webpack';
import * as Repack from '@callstack/repack';

export default (env) => {
  return {
    plugins: [
      new webpack.container.ModuleFederationPlugin({
        remotes: {
          app1: Repack.Federated.createRemote('app1'),
        },
      }),
    ],
  };
};
```

#### Parameters

| Name | Type | Description |
| :------ | :------ | :------ |
| `remoteName` | `string` | Name of the container to create remote for. |

#### Returns

`string`

A JavaScript loading code the the given remote.

#### Defined in

[webpack/federated.ts:36](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/federated.ts#L36)
