# Interface: RepackPluginConfig

[RepackPlugin](../classes/RepackPlugin.md) configuration options.

## Table of contents

### Properties

- [context](RepackPluginConfig.md#context)
- [devServer](RepackPluginConfig.md#devserver)
- [entryName](RepackPluginConfig.md#entryname)
- [extraChunks](RepackPluginConfig.md#extrachunks)
- [logger](RepackPluginConfig.md#logger)
- [mode](RepackPluginConfig.md#mode)
- [output](RepackPluginConfig.md#output)
- [platform](RepackPluginConfig.md#platform)
- [sourceMaps](RepackPluginConfig.md#sourcemaps)

## Properties

### context

• **context**: `string`

Context in which all resolution happens. Usually it's project root directory.

#### Defined in

[webpack/plugins/RepackPlugin.ts:14](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/RepackPlugin.ts#L14)

___

### devServer

• `Optional` **devServer**: [`DevServerOptions`](DevServerOptions.md)

Development server configuration options.
Used to configure `@callstack/repack-dev-server`.

If `undefined`, then development server will not be used.

#### Defined in

[webpack/plugins/RepackPlugin.ts:28](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/RepackPlugin.ts#L28)

___

### entryName

• `Optional` **entryName**: `string`

The entry chunk name, `main` by default.

#### Defined in

[webpack/plugins/RepackPlugin.ts:45](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/RepackPlugin.ts#L45)

___

### extraChunks

• `Optional` **extraChunks**: [`DestinationSpec`](../types/plugins.DestinationSpec.md)[]

Options specifying how to deal with extra chunks generated in the compilation,
usually by using dynamic `import(...)` function.

Refer to [OutputPluginConfig.extraChunks](plugins.OutputPluginConfig.md#extrachunks) for more details.

#### Defined in

[webpack/plugins/RepackPlugin.ts:53](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/RepackPlugin.ts#L53)

___

### logger

• `Optional` **logger**: `boolean` \| { `console?`: `boolean` ; `file?`: `string` ; `listener?`: (`logEntry`: [`LogEntry`](LogEntry.md)) => `void`  }

Options to configure [LoggerPlugin](../classes/plugins.LoggerPlugin.md)'s `output`.

Setting this to `false` disables [LoggerPlugin](../classes/plugins.LoggerPlugin.md).

#### Defined in

[webpack/plugins/RepackPlugin.ts:60](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/RepackPlugin.ts#L60)

___

### mode

• **mode**: ``"development"`` \| ``"production"``

Compilation mode.

#### Defined in

[webpack/plugins/RepackPlugin.ts:17](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/RepackPlugin.ts#L17)

___

### output

• **output**: `Object`

Output options specifying where to save generated bundle, source map and assets.

Refer to [OutputPluginConfig.output](plugins.OutputPluginConfig.md#output) for more details.

#### Type declaration

| Name | Type | Description |
| :------ | :------ | :------ |
| `assetsPath?` | `string` | Assets output path - directory where generated static assets will be saved. |
| `bundleFilename?` | `string` | Bundle output filename - name under which generated bundle will be saved. |
| `sourceMapFilename?` | `string` | Source map filename - name under which generated source map (for the main bundle) will be saved. |

#### Defined in

[webpack/plugins/RepackPlugin.ts:42](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/RepackPlugin.ts#L42)

___

### platform

• **platform**: `string`

Target application platform.

#### Defined in

[webpack/plugins/RepackPlugin.ts:20](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/RepackPlugin.ts#L20)

___

### sourceMaps

• `Optional` **sourceMaps**: `boolean`

Whether source maps should be generated. Defaults to `true`.

Setting this to `false`, disables any source map generation.

#### Defined in

[webpack/plugins/RepackPlugin.ts:35](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/RepackPlugin.ts#L35)
