# Interface: OutputPluginConfig

[plugins](../modules/plugins.md).OutputPluginConfig

[OutputPlugin](../classes/plugins.OutputPlugin.md) configuration options.

## Table of contents

### Properties

- [context](plugins.OutputPluginConfig.md#context)
- [enabled](plugins.OutputPluginConfig.md#enabled)
- [entryName](plugins.OutputPluginConfig.md#entryname)
- [extraChunks](plugins.OutputPluginConfig.md#extrachunks)
- [output](plugins.OutputPluginConfig.md#output)
- [platform](plugins.OutputPluginConfig.md#platform)

## Properties

### context

• **context**: `string`

Context in which all resolution happens. Usually it's project root directory.

#### Defined in

[webpack/plugins/OutputPlugin.ts:63](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/OutputPlugin.ts#L63)

___

### enabled

• `Optional` **enabled**: `boolean`

Whether the plugin is enabled. Defaults to `true`.

Useful when running with development server, in which case, it's not necessary for this plugin
to be enabled.

#### Defined in

[webpack/plugins/OutputPlugin.ts:74](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/OutputPlugin.ts#L74)

___

### entryName

• `Optional` **entryName**: `string`

The entry chunk name, `main` by default.

#### Defined in

[webpack/plugins/OutputPlugin.ts:77](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/OutputPlugin.ts#L77)

___

### extraChunks

• `Optional` **extraChunks**: [`DestinationSpec`](../types/plugins.DestinationSpec.md)[]

Options specifying how to deal with extra chunks generated in the compilation,
usually by using dynamic `import(...)` function.

By default all extra chunks will be saved under `<projectRoot>/build/outputs/<platform>/remotes` directory.

__Specifying custom value for this option, will disable default setting - you will need
to configure `outputPath` for `type: 'remote'` yourself.__

If you want to have some of the chunks available inside the `.ipa`/`.apk` file generated by React Native,
you must configure this options to match the chunks you want (using `test`/`include`/`exclude`)
and set the `type` to `local`, for example:
```ts
new OutputPlugin({
  context,
  platform,
  output,
  extraChunks: [
    {
      // Make `my-chunk` local
      include: /my-chunk/,
      type: 'local',
    },
    {
      // Make any other chunk remote
      exclude: /my-chunk/,
      type: 'remote',
      outputPath,
    },
  ]
});
```

#### Defined in

[webpack/plugins/OutputPlugin.ts:128](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/OutputPlugin.ts#L128)

___

### output

• **output**: `Object`

Output options specifying where to save generated bundle, source map and assets.

#### Type declaration

| Name | Type | Description |
| :------ | :------ | :------ |
| `assetsPath?` | `string` | Assets output path - directory where generated static assets will be saved. |
| `bundleFilename?` | `string` | Bundle output filename - name under which generated bundle will be saved. |
| `sourceMapFilename?` | `string` | Source map filename - name under which generated source map (for the main bundle) will be saved. |

#### Defined in

[webpack/plugins/OutputPlugin.ts:82](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/OutputPlugin.ts#L82)

___

### platform

• **platform**: `string`

Target application platform.

#### Defined in

[webpack/plugins/OutputPlugin.ts:66](https://github.com/callstack/repack/blob/a067171/packages/repack/src/webpack/plugins/OutputPlugin.ts#L66)
